# PLLPY
This is a wrapper for the [phylogenetic likelihood library](http://www.libpll.org/) (PLL) of the [Exelixis lab](http://sco.h-its.org/exelixis/index.html).

Install requirements:

- [cython](http://cython.org/)
- [autowrap](https://github.com/uweschmitt/autowrap)
- libpll installed from [git](https://www.assembla.com/code/phylogenetic-likelihood-library/git/nodes/master) - version 1.0.0 is too old

Installing libpll:

- on Mac PLL can be installed via [homebrew](http://brew.sh/) using the homebrew-science tap

   - `brew tap homebrew/homebrew-science`

   - `brew install --HEAD libpll`

Documentation will follow.